{% load bootstrap %}
<input type="{{ widget.type }}" name="{{ widget.name }}" {% if widget.value != None %}value="{{ widget.value|stringformat:'s' }}"{% endif %}{% bootstrap_attrs class="form-control" %}>
