{% load bootstrap %}

{% for error in form.non_field_errors %}
    <div class="alert alert-danger" role="alert">{{ error }}</div>
{% endfor %}

{% for field in form %}
    {% if field.is_hidden %}
        {{ field }}
    {% else %}
        {% bootstrap_field field %}
    {% endif %}
{% endfor %}
