{% if widget.is_initial %}
    <div>{{ widget.initial_text }}: <a href="{{ widget.value.url }}">{{ widget.value }}</a></div>
    {% if not widget.required %}
        <div class="form-check">
            <input type="checkbox" name="{{ widget.checkbox_name }}" id="{{ widget.checkbox_id }}" class="form-check-input"{% if widget.attrs.disabled %} disabled{% endif %}>
            <label for="{{ widget.checkbox_id }}" class="form-check-label">{{ widget.clear_checkbox_label }}</label>
        </div>
    {% endif %}
    {{ widget.input_text }}:
{% endif %}
{% include "django/forms/widgets/file.html" %}
